diff --git a/includes/navigation.php b/includes/navigation.php
index fc47d81..1ead138 100644
--- a/includes/navigation.php
+++ b/includes/navigation.php
@@ -9,7 +9,7 @@ if ($host == 'dev.dtch.online') {
Home
-
Last month %
+
Last quarter %
Last Matches
Top10
User Stats
diff --git a/last_stats.php b/last_stats.php
index 17642f1..14d7c3c 100644
--- a/last_stats.php
+++ b/last_stats.php
@@ -54,8 +54,8 @@ $ogDescription = "Explore detailed player statistics over the past month includi
echo "
";
echo "
| Player |
- AHD |
Win % |
+ AHD |
K/D Human |
Human Kills |
K/D All |
diff --git a/topstats.php b/topstats.php
index e5d9612..45c67f6 100644
--- a/topstats.php
+++ b/topstats.php
@@ -1,6 +1,6 @@
@@ -31,10 +31,10 @@ include './includes/header.php';
";
// Displaying top 10 comparisons for each attribute
$attributes = ['wins','top10s','kills','dBNOs','damageDealt','headshotKills','roadKills','teamKills','roundMostKills'];
foreach ($attributes as $attribute) {
- echo "Top 10 $attribute
";
+ echo "Top 20 $attribute
";
uasort($players_data[$selected_mode], function ($a, $b) use ($attribute) {
$account_id_a = array_key_first($a);
$account_id_b = array_key_first($b);
@@ -45,7 +45,7 @@ include './includes/header.php';
echo "
| Player | $attribute |
";
$count = 0;
foreach ($players_data[$selected_mode] as $player_name => $player_details) {
- if ($count++ >= 10) break; // Limit to top 10 players
+ if ($count++ >= 20) break; // Limit to top 20 players
$account_id = array_key_first($player_details);
echo "| $player_name | {$player_details[$account_id][$attribute]} |
";
@@ -31,10 +31,10 @@ include './includes/header.php';
";
- // Displaying top 10 comparisons for each attribute
+ // Displaying top 20 comparisons for each attribute
$attributes = ['wins','top10s','kills','dBNOs','damageDealt','headshotKills','roadKills','teamKills','roundMostKills'];
foreach ($attributes as $attribute) {
}